import{P as g}from"./PlayerNavbar-BqxflveB.js";import{e as _,ak as i,r as h,b,f as k,n as y,j as w,k as v,p as a,v as L,a4 as C,ag as N,g as c,aN as I}from"./jwt-decode.esm-CW3syEGH.js";import{u as V}from"./workspaceStore-Cap1w2e3.js";import"./userStore-gSalDeRH.js";import"./metadata-C6ujCDKU.js";import"./PhCursorClick.vue-BawSqjlL.js";import"./PhHouse.vue-B316XKnG.js";import"./PhMagnifyingGlass.vue-Blg131ek.js";import"./PhWebhooksLogo.vue-Adt_ItbF.js";import"./LoadingOutlined-5hOEIyqi.js";import"./PhSignOut.vue-CpPl8jWo.js";import"./index-C-fVyJWP.js";import"./runnerData-BU_xCjeZ.js";import"./url-D6c4Y6cf.js";import"./colorHelpers-DS1IpNI-.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="303bc59f-140c-4fc9-a634-be103f15e2e3",o._sentryDebugIdIdentifier="sentry-dbid-303bc59f-140c-4fc9-a634-be103f15e2e3")}catch{}})();const B={class:"main-container"},D={class:"content"},P=_({__name:"Main",setup(o){const e=N(),t=V(),p=i().path,n=h(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},d=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),k("div",B,[a(t).state.workspace?(c(),y(g,{key:0,"current-path":a(p),"hide-login":m.value,"runner-data":a(t).state.workspace,loading:n.value,"show-sidebar":a(t).state.currentPageType==="form",onNavigate:u,onLoginClick:l,onLogoutClick:d},null,8,["current-path","hide-login","runner-data","loading","show-sidebar"])):w("",!0),v("section",D,[L(f)])])}}}),J=I(P,[["__scopeId","data-v-61bdccea"]]);export{J as default};
//# sourceMappingURL=Main-BlU-2AYV.js.map
