import{_ as r}from"./logo-BiWG9_W5.js";import{L as d}from"./Logo-BcZCPtr8.js";import{e as o,n as s,p as i,g as a}from"./jwt-decode.esm-CW3syEGH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7d9eb5d5-39ed-4b75-9bf2-e295311d7838",e._sentryDebugIdIdentifier="sentry-dbid-7d9eb5d5-39ed-4b75-9bf2-e295311d7838")}catch{}})();const u=o({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(t,n)=>(a(),s(d,{"image-url":i(r),"brand-name":"Abstra","hide-text":e.hideText,size:e.size??"small"},null,8,["image-url","hide-text","size"]))}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang-BpDNV_zn.js.map
