import{B as l}from"./BaseLayout-B9yQXCxg.js";import{C as p}from"./ContentLayout-DyhnzARV.js";import{e as f,ak as _,b as i,F as b,a4 as g,n as r,g as s,w as c,v as y,j as w}from"./jwt-decode.esm-CW3syEGH.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-C99WvEM1.js";import{u as z}from"./projectsStore-Fwa-6LLt.js";import"./router-CbaJLHig.js";import"./ts.worker-DyQ6_83a.js";import"./index-DtwZWO9T.js";import"./member-pkKXgVYw.js";import"./organization-C3ds_9mJ.js";import"./project-E1D7b7jK.js";import"./tables-Q85pBdHB.js";import"./string-Cp9md8DE.js";import"./cascaderStore-DuIXvN4E.js";import"./organizationSwitcher-C4raT1gH.js";import"./ant-design-Dj3Xe6m5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ca078441-6f03-46a1-816b-67c58b9f6b60",t._sentryDebugIdIdentifier="sentry-dbid-ca078441-6f03-46a1-816b-67c58b9f6b60")}catch{}})();const P=f({__name:"Organization",setup(t){const e=_(),a=z(),n=i(()=>e.params.organizationId);b(n,o=>{o&&a.fetchedState?.organization?.id!==o&&a.fetchState(o)},{immediate:!0});const u=i(()=>a.fetchedState?.organization),m=i(()=>u.value?.billingMetadata);return(o,h)=>{const d=g("RouterView");return s(),r(l,null,{content:c(()=>[y(p,null,{default:c(()=>[m.value?(s(),r(v,{key:0,"billing-metadata":m.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(d,{key:n.value}))]),_:1})]),_:1})}}});export{P as default};
//# sourceMappingURL=Organization-BhYyYnFa.js.map
