import{N as c}from"./Navbar-DXsdbwPd.js";import{e as d,ak as u,b as a,l,a4 as f,f as _,g as b,v as p,k as y,aN as I}from"./jwt-decode.esm-CW3syEGH.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-2QMbdDLK.js";import"./constants-BsdSxe5K.js";import"./PhCaretDown.vue-tdmL1wTZ.js";import"./PhPencilSimple.vue-CfQBRJYR.js";import"./router-CbaJLHig.js";import"./ts.worker-DyQ6_83a.js";import"./organization-C3ds_9mJ.js";import"./tables-Q85pBdHB.js";import"./string-Cp9md8DE.js";import"./keyboard-DZuA_nQd.js";import"./os-CC2okSnD.js";import"./projectStore-DnWWPPaM.js";import"./project-E1D7b7jK.js";import"./organizationSwitcher-C4raT1gH.js";import"./cascaderStore-DuIXvN4E.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-bULqmTQO.js";import"./member-pkKXgVYw.js";import"./index-qiCtRIYr.js";import"./index-B6gCGsrU.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-DVqgSCsf.js";import"./PhNotePencil.vue-C5ciODUX.js";import"./PhSignOut.vue-CpPl8jWo.js";import"./index-hq5V4KLH.js";import"./index-C-fVyJWP.js";import"./PhPlus.vue-D26bMlr-.js";import"./omniChatStore-CphQbkuM.js";import"./files-BI4hwOd-.js";import"./contracts.generated-D8XoI9Pf.js";import"./runnerData-BU_xCjeZ.js";import"./url-D6c4Y6cf.js";import"./colorHelpers-DS1IpNI-.js";import"./uuid-C9n3OAHN.js";import"./PhCopySimple.vue-DQcD4BBT.js";import"./PhSparkle.vue-Dpn4esu7.js";import"./index-CeSx-Q5r.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="6f61c021-1367-4a0f-b736-e24a749c7bd2",r._sentryDebugIdIdentifier="sentry-dbid-6f61c021-1367-4a0f-b736-e24a749c7bd2")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",g,[p(e)])])}}}),io=I(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-dxvGyqtL.js.map
