import{aW as r,aX as n,a5 as o,aY as d,aZ as p,a_ as c,a$ as m,b0 as b,b1 as u,b2 as s,b3 as f,b4 as g,b5 as l}from"./jwt-decode.esm-CW3syEGH.js";import{b as y,s as w,g as _}from"./workspaceStore-Cap1w2e3.js";import{_ as h}from"./App.vue_vue_type_style_index_0_lang-7QqUJgHB.js";import{r as i}from"./router-DE1l6uiO.js";import"./userStore-gSalDeRH.js";import"./runnerData-BU_xCjeZ.js";import"./url-D6c4Y6cf.js";import"./colorHelpers-DS1IpNI-.js";import"./PlayerConfigProvider-BsM3GZLn.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="12d86235-d701-4b80-8ad6-421894072d0b",t._sentryDebugIdIdentifier="sentry-dbid-12d86235-d701-4b80-8ad6-421894072d0b")}catch{}})();class I{static init(){setInterval(()=>{y("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await _(),a=r(),e=n({render:()=>o(h)});d.init(),p(e,i,t),I.init(),e.use(i),e.use(a),e.use(c),e.mount("#app"),e.component("VSelect",m),e.component("Markdown",b),e.component("Message",u),s(e,f),s(e,g),s(e,l)})();
//# sourceMappingURL=player-CwY585OB.js.map
