import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DJhB8_pu.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-CW3syEGH.js";import{u as a}from"./projectStore-DnWWPPaM.js";import"./router-CbaJLHig.js";import"./ts.worker-DyQ6_83a.js";import"./fetch-DhTJz1uw.js";import"./tables-Q85pBdHB.js";import"./string-Cp9md8DE.js";import"./SaveButton-B8i5gPe1.js";import"./ExclamationCircleOutlined-Bi6SBFIh.js";import"./CrudView-DY6oSaHy.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BaE3LvL3.js";import"./constants-BsdSxe5K.js";import"./url-D6c4Y6cf.js";import"./PhDotsThreeVertical.vue-emniGe9l.js";import"./index-hq5V4KLH.js";import"./asyncComputed-lz1AJRFj.js";import"./PhPencil.vue-C7uiSx78.js";import"./useCodebaseEvents-CU17123O.js";import"./contracts.generated-D8XoI9Pf.js";import"./index-DtwZWO9T.js";import"./project-E1D7b7jK.js";import"./organizationSwitcher-C4raT1gH.js";import"./organization-C3ds_9mJ.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="15e73398-f47f-4176-97b6-756aa6049204",o._sentryDebugIdIdentifier="sentry-dbid-15e73398-f47f-4176-97b6-756aa6049204")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(f,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-D1l4WIFI.js.map
